AWSCloudFrontSignedUrl class

Constructors

AWSCloudFrontSignedUrl({required String keyPairId, required String privateKey})
Used to create CloudFront signed urls using custom policy https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-creating-signed-url-custom-policy.html
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keyPairId String
The ID for a CloudFront public key, for example, K2JCJMDEHXQW5F.
final
privateKey String
CloudFront private key The private key whose public key is in an active trusted key group for the distribution Usually starts with -----BEGIN RSA PRIVATE KEY-----
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signUrl({required String resourceUrl, DateTime? dateLessThan, DateTime? dateGreaterThan, String? ipAddress}) Future<String>
resourceUrl The base URL including your query strings, if any, for example: http://d111111abcdef8.cloudfront.net/images/horizon.jpg?size=large&license=yes
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited